#!/usr/bin/env python3

# Usage: comparison_with_other_probe_source_datasets.py a.csv b.csv c.csv comparison_with_other_probe_source_datasets.pdf

import getopt
import sys

import matplotlib.pyplot as plt
import matplotlib
from matplotlib_venn import venn3, venn3_unweighted

import common
matplotlib.pyplot.rcParams.update({"font.size": 14})

FIGSIZE = (5, 4)

# Read packets from CSV.
_, (dunna_ips, ensafi_ips, ss_ips, output_filename) = getopt.gnu_getopt(sys.argv[1:], "")

# source: https://adunna.me/projects/dist/foci-2018-tor/Data/analysis-only-SYN.csv
tor_active_probing_src_ips = [line.rstrip() for line in open(dunna_ips)]

# source: https://ensa.fi/active-probing/#code
probers_active_probing_src_ips = [line.rstrip() for line in open(ensafi_ips)]

ss_active_probing_src_ips = [line.rstrip() for line in open(ss_ips)]

fig = plt.figure(figsize=FIGSIZE)
ax = plt.axes()
ax.margins(0, 0)

def desaturate_rgb(rgb, t = 0.6):
    return tuple(c + t * (1.0 - c) for c in rgb)

v = venn3([set(ss_active_probing_src_ips), \
                  set(tor_active_probing_src_ips), \
                  set(probers_active_probing_src_ips)], \
    set_labels = ("",)*3,
    alpha = 1.0, # Default is 0.4, but LibreOffice PDF export discards transparency and makes the circles much darker...
    set_colors = (desaturate_rgb((1.0, 0.0, 0.0)),
                  desaturate_rgb((0.0, 0.5, 0.0)),
                  desaturate_rgb((0.0, 0.0, 1.0))),
)

ax.text(
        0.35, 0.05,
        "Tor active probes\n(Dunna et al. 2018)",
        transform=ax.transAxes,
        horizontalalignment="center", verticalalignment="center",
        fontsize=16,
    )

ax.text(
        0.15, 0.85,
        "Shadowsocks\nactive probes\n(this work)",
        transform=ax.transAxes,
        horizontalalignment="center", verticalalignment="center",
        fontsize=16,
    )

ax.text(
        0.85, 0.35,
        "Various active probes\n(Ensafi et al. 2015)",
        transform=ax.transAxes,
        horizontalalignment="center", verticalalignment="center",
        fontsize=16,
    )


# legend = ax.legend(bbox_to_anchor=(0.62, 0.72), fontsize="small")
# # Make legend markers fully opaque: https://stackoverflow.com/a/42403471.
# for handle in legend.legendHandles:
#     handle._legmarker.set_alpha(1)

#fig.subplots_adjust(left=0.25, bottom=0.08, right=0.9, top=0.96)
plt.savefig(output_filename, metadata={"CreationDate": None})

